import type {AddViewConfig} from '@/helpers/models';

export const addViewConfig: AddViewConfig = {
  pages: [
    {
      label: 'General',
      name: 'general',
      fieldsets: [
        {
          label: 'Basic settings',
          name: 'general__basicSettings',
          rows: [
            [
              {
                type: 'UInputText',
                props: {
                  name: 'firstname',
                  label: 'First name',
                  required: true,
                  access: 'write',
                },
              },
              {
                type: 'UInputText',
                props: {
                  name: 'lastname',
                  label: 'Last name',
                  required: true,
                  access: 'write',
                },
              },
            ],
            [
              {
                type: 'UInputText',
                props: {
                  name: 'name',
                  label: 'Username',
                  required: true,
                  access: 'write',
                },
              },
              {
                type: 'UInputDate',
                props: {
                  name: 'birthday',
                  label: 'Birthday',
                  required: false,
                  access: 'write',
                },
              },
            ],
            [
              {
                type: 'UInputText',
                props: {
                  name: 'primaryMail',
                  label: 'Primary mail address',
                  required: false,
                  access: 'write',
                },
              },
            ],
            [
              {
                type: 'UInputPassword',
                props: {
                  name: 'password',
                  label: 'Password',
                  required: false,
                  access: 'write',
                },
              },
            ],
            [
              {
                type: 'UInputCheckbox',
                props: {
                  label: 'Disabled',
                  name: 'disabled',
                  required: false,
                  access: 'write',
                },
              },
            ],
          ],
        },
        {
          label: 'Account',
          name: 'general__account',
          rows: [
            [
              {
                type: 'UInputDate',
                props: {
                  name: 'accountActivationDate',
                  label: 'Activation date',
                  required: false,
                  access: 'write',
                },
              },
            ],
            [
              {
                type: 'UInputDate',
                props: {
                  name: 'expirationDate',
                  label: 'Expiration date',
                  required: false,
                  access: 'write',
                },
              },
            ],
          ],
        },
        {
          label: 'UCS@school',
          name: 'ucs@school',
          rows: [
            [
              {
                type: 'UComboBox',
                props: {
                  name: 'school',
                  label: 'Primary school',
                  required: true,
                  access: 'write',
                  options: [
                    {
                      label: 'School1',
                      value: 'school1',
                    },
                    {
                      label: 'School2',
                      value: 'school2',
                    },
                  ],
                },
              },
            ],
            [
              {
                type: 'UMultiSelect',
                props: {
                  name: 'schoolClasses',
                  label: 'School classes',
                  required: true,
                  access: 'write',
                  columns: [
                    {
                      label: 'Select all',
                      attribute: 'label',
                    },
                  ],
                  rows: [
                    {
                      id: 'school1-1a',
                      attributes: {
                        label: {
                          value: '1A',
                          access: 'read',
                        },
                      },
                    },
                    {
                      id: 'school1-2a',
                      attributes: {
                        label: {
                          value: '2A',
                          access: 'read',
                        },
                      },
                    },
                    {
                      id: 'school1-3a',
                      attributes: {
                        label: {
                          value: '3A',
                          access: 'read',
                        },
                      },
                    },
                  ],
                },
              },
            ],
            [
              {
                type: 'UComboBox',
                props: {
                  name: 'role',
                  label: 'Role',
                  required: true,
                  access: 'write',
                  options: [
                    {
                      value: 'student',
                      label: 'Lernende',
                    },
                    {
                      value: 'generic_user',
                      label: 'Nutzende',
                    },
                    {
                      value: 'teacher',
                      label: 'Lehrende',
                    },
                    {
                      value: 'school_admin',
                      label: 'Schuladmins',
                    },
                    {
                      value: 'technical_admin',
                      label: 'Fachliche Leitstelle',
                    },
                  ],
                },
              },
            ],
          ],
        },
      ],
    },
  ],
};
