import type {UGridRow, UGridColumnDefinition, SubElementProps} from '@univention/univention-veb';

export interface LabeledValue<T> {
  value: T;
  label: string;
}

// This should be coming from the apiTypes, but is not implemented yet
export type SourceUid = 'IDI' | 'Manuell';

export interface Column {
  label: string;
  attribute: string;
  formatter?: string;
  sortFormatter?: string;
  sorting?: 'asc' | 'dec' | 'none';
}

export type GlobalAction = 'add';
export interface ListViewConfig {
  url: string;
  allowedGlobalActions: GlobalAction[];
  searchFormOptions: {
    schools: LabeledValue<string>[];
    activationStates: LabeledValue<string>[];
    networkAccess: LabeledValue<string>[];
    roles: LabeledValue<string>[];
  };
  columns: Column[];
}

export interface AddViewConfig {
  pages: Page[];
}

export type Access = 'none' | 'read' | 'write';
export type ContextAction = 'delete' | 'edit' | 'setPassword' | 'setWifiPassword' | 'toggleActive' | 'toggleWifi' | 'exportCSV';

export interface Attribute {
  value?: unknown;
  access: Access;
}
export interface UserListResponseModel {
  id: string;
  allowedActions: ContextAction[];
  attributes: Record<string, Attribute>;
}

export interface FieldInputText {
  type: 'UInputText';
  props: {
    name: string;
    label: string;
    // modelValue: string;
    description?: string;
    required?: boolean;
    access?: 'write' | 'read' | 'none';
  };
}
export interface FieldInputDate {
  type: 'UInputDate';
  props: {
    name: string;
    label: string;
    // modelValue: string;
    description?: string;
    required?: boolean;
    access?: 'write' | 'read' | 'none';
  };
}
export interface FieldInputPassword {
  type: 'UInputPassword';
  props: {
    name: string;
    label: string;
    // modelValue: string;
    description?: string;
    required?: boolean;
    access?: 'write' | 'read' | 'none';
  };
}
export interface FieldInputCheckbox {
  type: 'UInputCheckbox';
  props: {
    name: string;
    label: string;
    // modelValue: string;
    description?: string;
    required?: boolean;
    access?: 'write' | 'read' | 'none';
  };
}
export interface FieldSelect {
  type: 'USelect';
  props: {
    name: string;
    label: string;
    // modelValue: string;
    description?: string;
    required?: boolean;
    access?: 'write' | 'read' | 'none';
    options: {label: string; value: string}[];
  };
}
export interface FieldComboBox {
  type: 'UComboBox';
  props: {
    name: string;
    label: string;
    // modelValue: string;
    description?: string;
    required?: boolean;
    access?: 'write' | 'read' | 'none';
    options: {label: string; value: string}[];
  };
}
export interface FieldMultiSelect {
  type: 'UMultiSelect';
  props: {
    name: string;
    label: string;
    // modelValue: string;
    description?: string;
    required?: boolean;
    access?: 'write' | 'read' | 'none';
    columns: UGridColumnDefinition[];
    rows: UGridRow[];
  };
}
export interface FieldMultiInput {
  type: 'UMultiInput';
  props: {
    name: string;
    label: string;
    required: boolean;
    access?: 'write' | 'read' | 'none';
    subElements: Field[];
    description?: string;
  };
}
export interface FieldMultiObjectSelect {
  type: 'UMultiObjectSelect';
  props: {
    name: string;
    label: string;
    // modelValue: string;
    description?: string;
    required?: boolean;
    access?: 'write' | 'read' | 'none';

    initialRows: UGridRow[];
    columns: UGridColumnDefinition[];

    searchStandby: boolean;
    searchRows: UGridRow[];
    searchElements: SubElementProps[];
    searchColumns: UGridColumnDefinition[];
    searchCallback?: (values: Record<string, unknown>) => void;
  };
}
export interface FieldInputClassified {
  type: 'UInputClassified';
  props: {
    name: string;
    label: string;
    description?: string;
    access?: 'none';
  };
}
export type Field =
  FieldComboBox |
  FieldInputCheckbox |
  FieldInputClassified |
  FieldInputDate |
  FieldInputPassword |
  FieldInputText |
  FieldMultiInput |
  FieldMultiObjectSelect |
  FieldMultiSelect |
  FieldSelect;


export interface Fieldset {
  label: string;
  name: string;
  rows: (Field | Field[])[];
}

export interface Page {
  label: string;
  name: string;
  fieldsets: Fieldset[];
}

export type FormValues = Record<string, unknown>;
export type DetailAction = 'save';
export interface UserDetailResponseModel {
  url: string;
  allowedActions: DetailAction[];
  pages: Page[];
  values: FormValues;
}

export type ToggleActiveAction = 'activate' | 'deactivate';
export type ToggleWifiActiveAction = 'activate' | 'deactivate';
